@@ -1,5 +1,5 @@
 from librec_auto.core.cmd import Cmd
-from librec_auto.core.util import Files, SubPaths
+from librec_auto.core.util import Files, ExpPaths
 from librec_auto.core import ConfigCmd
 from librec_auto.core.util import confirm
 import shutil
@@ -13,11 +13,11 @@ class SetupCmd(Cmd):
     def setup(self, args):
         pass
 
-    def dry_run(self, config):
+    def dry_run(self, config: ConfigCmd):
         print(f"librec-auto (DR): Executing setup command {self}")
         config.ensure_experiments()
         config.setup_exp_configs()
 
-    def execute(self, config: ConfigCmd):
-        config.ensure_experiments()
-        config.setup_exp_configs()
+    def execute(self, config: ConfigCmd, startval = None, exp_no = None):
+        config.ensure_experiments(exp_no)
+        config.setup_exp_configs(startval)
