@@ -1,9 +1,7 @@
 from librec_auto.core.cmd import Cmd
 from librec_auto.core.util import Files
 from librec_auto.core import ConfigCmd
-from librec_auto.core.util import LogFile, Status
-import sys
-import subprocess
+from librec_auto.core.util import Status
 
 
 class StatusCmd(Cmd):
@@ -19,14 +17,14 @@ class StatusCmd(Cmd):
     def execute(self, config: ConfigCmd):
         self.status = Cmd.STATUS_INPROC
         files = config.get_files()
-        target = files.get_exp_path()
+        target = files.get_study_path()
         #        result_path = files.get_result_path()
 
-        if files.get_sub_count() == 0:
+        if files.get_exp_count() == 0:
             print("librec-auto: No experiments found.")
         else:
-            for sub_paths in files.get_sub_paths_iterator():
-                status = Status(sub_paths)
+            for exp_paths in files.get_exp_paths_iterator():
+                status = Status(exp_paths)
                 print(status)
 
         self.status = Cmd.STATUS_COMPLETE
